@@ -8,6 +8,11 @@
 #include <glib/gstdio.h>
 #include <string.h>
 #include <signal.h>
+#ifdef MAEMO2
+  #include <hildon-fm/hildon-widgets/hildon-file-chooser-dialog.h>
+  #include <hildon-widgets/hildon-defines.h>
+  #include <gdk/gdkkeysyms.h>
+#endif
 
 #include "callbacks.h"
 #include "interface.h"
@@ -43,7 +48,11 @@ void set_checkbox(void* main, gchar* name, gboolean val) {
 
 void set_main_title(gchar* session, gchar* extra) {
 	gchar *stmp;
+#ifdef MAEMO2
+	stmp = g_strconcat(session, " ", extra, NULL);
+#else
 	stmp = g_strconcat("Grsync: ", session, " ", extra, NULL);
+#endif
 	gtk_window_set_title((GtkWindow*) main_window, stmp);
 	g_free(stmp);
 }
@@ -283,8 +292,12 @@ gboolean load_groups(GtkWidget* main, gchar *session) {
 void show_browse_source(GtkButton *button, gpointer user_data) {
 	GtkWidget *dialog;
 	gint retval;
+#ifdef MAEMO2
+	dialog = hildon_file_chooser_dialog_new (NULL, GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
+#else
 	dialog = gtk_file_chooser_dialog_new (_("Browse"), (GtkWindow*) main_window, GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
+#endif
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog),
 		gtk_entry_get_text((GtkEntry*) lookup_widget((GtkWidget*) button, "text_source")));
 
@@ -304,8 +317,12 @@ void show_browse_source(GtkButton *button, gpointer user_data) {
 void show_browse_dest(GtkButton *button, gpointer user_data) {
 	GtkWidget *dialog;
 	gint retval;
+#ifdef MAEMO2
+	dialog = hildon_file_chooser_dialog_new (NULL, GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
+#else
 	dialog = gtk_file_chooser_dialog_new (_("Browse"), (GtkWindow*) main_window, GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
+#endif
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog),
 		gtk_entry_get_text((GtkEntry*) lookup_widget((GtkWidget*) button, "text_dest")));
 
@@ -444,7 +461,8 @@ void on_main_create(GtkWindow *window, gpointer user_data) {
 		gtk_dialog_run(GTK_DIALOG(error));
 		gtk_widget_destroy(error);
 	} else {
-//		g_spawn_command_line_sync("man rsync", &rsync_man, NULL, NULL, NULL);
+#ifndef MAEMO2
+	//	g_spawn_command_line_sync("man rsync", &rsync_man, NULL, NULL, NULL);
 		rsync_tips = gtk_tooltips_new();
 		set_tooltip(rsync_tips, "--times", "check_time");
 		set_tooltip(rsync_tips, "--perms", "check_perm");
@@ -464,6 +482,7 @@ void on_main_create(GtkWindow *window, gpointer user_data) {
 		set_tooltip(rsync_tips, "--numeric-ids", "check_mapuser");
 		set_tooltip(rsync_tips, "--compress", "check_compr");
 		set_tooltip(rsync_tips, "--backup", "check_backup");
+#endif
 	}
 	g_free(stmp);
 }
@@ -733,6 +752,12 @@ void on_rsync_show(GtkWidget *widget, gpointer user_data) {
 	g_free(comm_str);
 
 	view = (GtkTextView*)lookup_widget(widget, "textview_output");
+	#ifdef MAEMO2
+	PangoFontDescription *font_desc = pango_font_description_new ();
+	pango_font_description_set_size (font_desc, 10 * PANGO_SCALE);
+	gtk_widget_modify_font (GTK_WIDGET (view), font_desc);
+	pango_font_description_free (font_desc);
+	#endif
 	buffer = gtk_text_view_get_buffer(view);
 	gtk_text_buffer_insert_at_cursor(buffer, comm_text, -1);
 	if (config_log) fputs(comm_text, log_file);
@@ -944,6 +969,14 @@ void on_rsync_info_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
 	tmps = g_strconcat(config_command, " --version", NULL);
 	g_spawn_command_line_sync(tmps, &result, NULL, NULL, NULL);
+#ifdef MAEMO2
+	if (result) {
+		gchar *nn;
+		nn = strstr(result, "\n\n");
+		if (nn) *nn = 0;
+		g_free(nn);
+	}
+#endif
 	dialog = gtk_message_dialog_new((GtkWindow*) main_window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, result);
 	gtk_dialog_run(GTK_DIALOG(dialog));
 
@@ -951,3 +984,17 @@ void on_rsync_info_activate(GtkMenuItem *menuitem, gpointer user_data) {
 	g_free(tmps);
 	g_free(result);
 }
+
+#ifdef MAEMO2
+gboolean hardware_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_data) {
+	switch (event->keyval) {
+		case HILDON_HARDKEY_FULLSCREEN :
+			if (!(gdk_window_get_state (event->window) &
+			    GDK_WINDOW_STATE_FULLSCREEN)) gtk_window_fullscreen (GTK_WINDOW (widget));
+			else gtk_window_unfullscreen (GTK_WINDOW (widget));
+			return TRUE;
+	}	
+	return FALSE;
+}
+#endif
+
